View source: R/adjust_weights_parametric_util.R
| c_value_function | R Documentation |
An intersection hypothesis can be rejected if its p-values are less than or
equal to their adjusted significance levels, which are their adjusted
hypothesis weights times \alpha. For Bonferroni tests, their adjusted
hypothesis weights are their hypothesis weights of the intersection
hypothesis. Additional adjustment is needed for parametric tests:
Parametric tests for adjust_weights_parametric(),
Note that one-sided tests are required for parametric tests.
c_value_function(
x,
hypotheses,
test_corr,
alpha,
maxpts = 25000,
abseps = 1e-06,
releps = 0
)
solve_c_parametric(
hypotheses,
test_corr,
alpha,
maxpts = 25000,
abseps = 1e-06,
releps = 0
)
adjust_weights_parametric_util(
matrix_weights,
matrix_intersections,
test_corr,
alpha,
test_groups,
maxpts = 25000,
abseps = 1e-06,
releps = 0
)
x |
The root to solve for with |
hypotheses |
A numeric vector of hypothesis weights. Must be a vector of values between 0 & 1 (inclusive). The sum of hypothesis weights should not exceed 1. |
test_corr |
(Optional) A numeric matrix of correlations between test
statistics, which is needed to perform parametric tests using
|
alpha |
(Optional) A numeric value of the overall significance level, which should be between 0 & 1. The default is 0.025 for one-sided hypothesis testing problems; another common choice is 0.05 for two-sided hypothesis testing problems. Note when parametric tests are used, only one-sided tests are supported. |
maxpts |
(Optional) An integer scalar for the maximum number of function
values, which is needed to perform parametric tests using the
|
abseps |
(Optional) A numeric scalar for the absolute error tolerance,
which is needed to perform parametric tests using the |
releps |
(Optional) A numeric scalar for the relative error tolerance
as double, which is needed to perform parametric tests using the
|
c_value_function() returns the difference between
\alpha and the Type I error of the parametric test with the c
value of x, adjusted for the correlation between test statistics using
parametric tests based on equation (6) of Xi et al. (2017).
solve_c_parametric() returns the c value adjusted for the
correlation between test statistics using parametric tests based on
equation (6) of Xi et al. (2017).
Xi, D., Glimm, E., Maurer, W., and Bretz, F. (2017). A unified framework for weighted parametric multiple test procedures. Biometrical Journal, 59(5), 918-931.
adjust_weights_parametric() for adjusted hypothesis weights using
parametric tests.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.