| edge_pairs | R Documentation |
For an initial graph, find pairs of hypotheses that are connected in both
directions. This is used to plot graphs using plot.initial_graph().
edge_pairs(graph)
graph |
An initial graph as returned by |
A list of vertex pairs which are connected in both directions. NULL if no such pairs are found.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.