graphicalMCP-package: graphicalMCP: Graphical Multiple Comparison Procedures

graphicalMCP-packageR Documentation

graphicalMCP: Graphical Multiple Comparison Procedures

Description

logo

Multiple comparison procedures (MCPs) control the familywise error rate in clinical trials. Graphical MCPs include many commonly used procedures as special cases; see Bretz et al. (2011) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/bimj.201000239")}, Lu (2016) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/sim.6985")}, and Xi et al. (2017) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/bimj.201600233")}. This package is a low-dependency implementation of graphical MCPs which allow mixed types of tests. It also includes power simulations and visualization of graphical MCPs.

Author(s)

Maintainer: Dong Xi dong.xi1@gilead.com

Authors:

Other contributors:

  • Gilead Sciences, Inc. [copyright holder, funder]

See Also

Useful links:


graphicalMCP documentation built on June 8, 2025, 11:19 a.m.