View source: R/plot.updated_graph.R
| plot.updated_graph | R Documentation |
updated_graphPlotting an updated graph is a very light wrapper around
plot.initial_graph(), only changing the default vertex color to use gray
for deleted hypotheses.
## S3 method for class 'updated_graph'
plot(x, ...)
x |
An object of class |
... |
Arguments passed on to
|
An object x of class updated_graph, after plotting the updated
graph.
Bretz, F., Posch, M., Glimm, E., Klinglmueller, F., Maurer, W., and Rohmeyer, K. (2011). Graphical approaches for multiple comparison procedures using weighted Bonferroni, Simes, or parametric tests. Biometrical Journal, 53(6), 894-913.
plot.initial_graph() for the plot method for the initial graph.
# A graphical multiple comparison procedure with two primary hypotheses (H1
# and H2) and two secondary hypotheses (H3 and H4)
# See Figure 1 in Bretz et al. (2011).
hypotheses <- c(0.5, 0.5, 0, 0)
transitions <- rbind(
c(0, 0, 1, 0),
c(0, 0, 0, 1),
c(0, 1, 0, 0),
c(1, 0, 0, 0)
)
g <- graph_create(hypotheses, transitions)
# Delete the second and third hypotheses in the "unordered mode"
plot(
graph_update(
g,
c(FALSE, TRUE, TRUE, FALSE)
),
layout = "grid"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.